kdict package
=============

Submodules
----------

kdict.core module
-----------------

.. automodule:: kdict.core
   :members:
   :undoc-members:
   :show-inheritance:

kdict.helpers module
--------------------

.. automodule:: kdict.helpers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: kdict
   :members:
   :undoc-members:
   :show-inheritance:
